@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::Init2 2.49 {
+package Dist::Zilla::Plugin::Author::Plicease::Init2 2.50 {
 
   use 5.014;
   use Moose;
@@ -82,6 +82,17 @@ package Dist::Zilla::Plugin::Author::Plicease::Init2 2.49 {
     },
   );
 
+  has irc => (
+    is      => 'ro',
+    isa     => 'Maybe[Str]',
+    lazy    => 1,
+    default => sub {
+      my $self = shift;
+      return undef unless $self->chrome->prompt_yn("irc?");
+      $self->chrome->prompt_str("irc url", { default => 'irc://irc.perl.org/#native' });
+    },
+  );
+
   has perl_version => (
     is      => 'ro',
     lazy    => 1,
@@ -208,6 +219,7 @@ package Dist::Zilla::Plugin::Author::Plicease::Init2 2.49 {
       github_user    => $self->github_user,
       version_plugin => ($self->perl_version >= 5.014 ? 'PkgVersion::Block' : 0),
       workflow       => $self->workflow,
+      irc            => $self->irc,
       default_branch => 'main',
     };
 
@@ -373,7 +385,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 2.49
+version 2.50
 
 =head1 DESCRIPTION
 
@@ -455,6 +467,9 @@ jobs:
     - env: CIP_TAG=5.12
     - env: CIP_TAG=5.10
     - env: CIP_TAG=5.8
+branches:
+  only:
+    - main
 cache:
   directories:
     - "$HOME/.cip"
@@ -578,6 +593,7 @@ test2_v0       = 1
   }
 
   $extra .= "version_plugin = $version_plugin\n" if $version_plugin;
+  $extra .= "irc            = $irc\n" if $irc;
 
   $extra;
 
